==> ovirt-engine-3.3.1.tar.gz: frontend/webadmin/modules/webadmin/src/main/java/org/ovirt/engine/ui/webadmin/ApplicationResources.java <==
package org.ovirt.engine.ui.webadmin;

import org.ovirt.engine.ui.common.CommonApplicationResources;

import com.google.gwt.resources.client.ImageResource;

public interface ApplicationResources extends CommonApplicationResources {

    @Source("images/bg.png")
    ImageResource bgImage();

    @Source("images/bookmark.gif")
    ImageResource bookmarkImage();

    @Source("images/but_erase_search_bar_text_normal.png")
    ImageResource clearSearchImage();

    @Source("images/but_erase_search_bar_text_hover.png")
    ImageResource clearSearchImage_mouseOver();

    @Source("images/but_erase_search_bar_text_mousedown.png")
    ImageResource clearSearchImage_mouseDown();

    @Source("images/cluster.png")
    ImageResource clusterImage();

    @Source("images/clusters.png")
    ImageResource clustersImage();

    @Source("images/console_disabled.png")
    ImageResource consoleDisabledImage();

    @Source("images/console.png")
    ImageResource consoleImage();

    @Source("images/datacenter.png")
    ImageResource dataCenterImage();

    @Source("images/datacenters.png")
    ImageResource dataCentersImage();

    @Override
    @Source("images/disk.png")
    ImageResource diskImage();

    @Source("images/error.gif")
    ImageResource errorImage();

    @Source("images/events_gray.png")
    ImageResource eventsGrayImage();

    @Source("images/events.png")
    ImageResource eventsImage();

    @Source("images/icon_foreman.png")
    ImageResource foremanImage();

    @Source("images/btn_guide_hover.png")
    ImageResource guideHoverMediumImage();

    @Source("images/guide.png")
    ImageResource guideImage();

    @Source("images/btn_guide.png")
    ImageResource guideMediumImage();

    @Source("images/btn_guide_pressed.png")
    ImageResource guidePressedMediumImage();

    @Source("images/icn_guide_disabled.png")
    ImageResource guideSmallDisabledImage();

    @Source("images/icn_guide.png")
    ImageResource guideSmallImage();

    @Source("images/bookmark.gif")
    ImageResource headerSearchBookmarkImage();

    @Source("images/search_button.png")
    ImageResource headerSearchButtonImage();

    @Source("images/host_error.gif")
    ImageResource hostErrorImage();

    @Source("images/host.png")
    ImageResource hostImage();

    @Source("images/host_installing.png")
    ImageResource hostInstallingImage();

    @Source("images/hosts.png")
    ImageResource hostsImage();

    @Source("images/Lock.png")
    ImageResource lockImage();

    @Source("images/icn_external_policy.png")
    ImageResource exteranlPolicyUnitImage();

    @Source("images/logo.png")
    ImageResource logoImage();

    @Source("images/host_maintenance.png")
    ImageResource maintenanceImage();

    @Source("images/many_desktops.png")
    ImageResource manyDesktopsImage();

    @Source("images/minus.png")
    ImageResource minusImage();

    @Source("images/monitor.png")
    ImageResource monitorImage();

    @Source("images/nonoperational.png")
    ImageResource nonOperationalImage();

    @Source("images/icon_openstack.png")
    ImageResource openstackImage();

    @Source("images/pause.gif")
    ImageResource pauseImage();

    @Source("images/icn_suspend_disabled.png")
    ImageResource suspendVmDisabledImage();

    @Source("images/icn_suspend_enabled.png")
    ImageResource suspendVmImage();

    @Source("images/play.gif")
    ImageResource playImage();

    @Source("images/plus_disabled.png")
    ImageResource plusDisabledImage();

    @Source("images/plus.png")
    ImageResource plusImage();

    @Source("images/icon_providers.png")
    ImageResource providersImage();

    @Source("images/log_warning.gif")
    ImageResource alertImage();

    @Source("images/tag_locked.png")
    ImageResource readOnlyTagImage();

    @Source("images/icn_play_disabled.png")
    ImageResource runVmDisabledImage();

    @Source("images/icn_play.png")
    ImageResource runVmImage();

    @Source("images/search_button.png")
    ImageResource searchButtonImage();

    @Source("images/split.png")
    ImageResource splitImage();

    @Source("images/split-rotate.png")
    ImageResource splitRotateImage();

    @Source("images/stop.gif")
    ImageResource stopImage();

    @Source("images/icn_stop_disabled.png")
    ImageResource stopVmDisabledImage();

    @Source("images/icn_stop.png")
    ImageResource stopVmImage();

    @Source("images/storages.png")
    ImageResource storagesImage();

    @Source("images/system.png")
    ImageResource systemImage();

    @Source("images/tag.png")
    ImageResource tagImage();

    @Source("images/icn_tag_link_disabled.gif")
    ImageResource tagLinkDisabledImage();

    @Source("images/icn_tag_link.png")
    ImageResource tagLinkImage();

    @Source("images/tag_pin_green.png")
    ImageResource tagPinGreenImage();

    @Source("images/tag_pin.png")
    ImageResource tagPinImage();

    @Source("images/torn_chain.png")
    ImageResource tornChainImage();

    @Source("images/unconfigured.png")
    ImageResource unconfiguredImage();

    @Source("images/upalert.png")
    ImageResource upalertImage();

    @Source("images/user_group.png")
    ImageResource userGroupImage();

    @Source("images/vm.png")
    ImageResource vmImage();

    @Source("images/window_bg.png")
    ImageResource windowBgImage();

    @Source("images/window_header.png")
    ImageResource windowHeaderImage();

    @Source("images/wrench.png")
    ImageResource wrenchImage();

    @Source("images/plusButton.png")
    ImageResource plusButtonImage();

    @Source("images/enlarge_bottom_panel.png")
    ImageResource enlargeFooterPanelImage();

    @Source("images/button/footer_button_start.png")
    ImageResource footerButtonUpStart();

    @Source("images/button/footer_button_stretch.png")
    ImageResource footerButtonUpStretch();

    @Source("images/button/footer_button_end.png")
    ImageResource footerButtonUpEnd();

    @Source("images/button/footer_button_Down_start.png")
    ImageResource footerButtonDownStart();

    @Source("images/button/footer_button_Down_stretch.png")
    ImageResource footerButtonDownStretch();

    @Source("images/button/footer_button_Down_end.png")
    ImageResource footerButtonDownEnd();

    @Source("images/icon_task.png")
    ImageResource iconTask();

    @Source("images/icon_audit.png")
    ImageResource iconAudit();

    @Source("images/icon_disable.png")
    ImageResource iconDisable();

    @Source("images/icon_enforce.png")
    ImageResource iconEnforce();

    @Source("images/icon_collapse_all.png")
    ImageResource collapseAllIcon();

    @Source("images/network/arrow_left.png")
    ImageResource arrowLeft();

    @Source("images/network/arrow_right_bottom.png")
    ImageResource arrowRightBottom();

    @Source("images/network/arrow_right_middle.png")
    ImageResource arrowRightMiddle();

    @Source("images/network/arrow_right_one.png")
    ImageResource arrowRightOne();

    @Source("images/network/arrow_right_top.png")
    ImageResource arrowRightTop();

    @Source("images/network/item_draggable.png")
    ImageResource itemDraggable();

    @Source("images/network/mgmt_net.png")
    ImageResource mgmtNetwork();

    @Source("images/network/network_monitor.png")
    ImageResource networkMonitor();

    @Source("images/network/network_vm.png")
    ImageResource networkVm();

    @Source("images/network/migration_network.png")
    ImageResource migrationNetwork();

    @Source("images/network/empty.png")
    ImageResource networkEmpty();

    @Source("images/network/nic_down.png")
    ImageResource nicDown();

    @Source("images/network/nic_up.png")
    ImageResource nicUp();

    @Source("images/network/edit_hover.png")
    ImageResource editHover();

    @Source("images/network/edit_mousedown.png")
    ImageResource editMouseDown();

    @Source("images/network/nic_icon.png")
    ImageResource nicIcon();

    @Source("images/network/bond.png")
    ImageResource bond();

    @Source("images/network/network_not_sync.png")
    ImageResource networkNotSyncImage();

    @Source("images/network/but_erase_net_mousedown.png")
    ImageResource butEraseNetMousedown();

    @Source("images/network/but_erase_net_hover.png")
    ImageResource butEraseNetHover();

    @Source("images/cluster_gluster.png")
    ImageResource glusterClusterImage();

    @Source("images/single_volume.png")
    ImageResource volumeImage();

    @Source("images/multiple_volumes.png")
    ImageResource volumesImage();

    @Source("images/icn_tree_network.png")
    ImageResource networkTreeImage();

    @Source("images/icn_tree_networks.png")
    ImageResource networksTreeImage();

    // Vm Types
    @Source("images/vmType/desktop.gif")
    ImageResource desktopImage();

    @Source("images/vmType/server.png")
    ImageResource serverImage();

    @Source("images/vmType/vm_desktop_stateless.png")
    ImageResource desktopStateless();

    @Source("images/vmType/vm_server_stateless.png")
    ImageResource serverStateless();

    // custom statuses
    @Source("images/vmStatus/running.png")
    ImageResource vmStatusRunning();

    @Source("images/vmStatus/starting.png")
    ImageResource vmStatusStarting();

    @Source("images/vmStatus/rebootInProgress.png")
    ImageResource rebootInProgress();

    @Source("images/vmStatus/wait.png")
    ImageResource vmStatusWait();

    @Source("images/vmStatus/waitForLaunch.png")
    ImageResource waitForLaunch();

    @Source("images/vmStatus/down.png")
    ImageResource downStatusImage();

    @Source("images/vmStatus/stopping.png")
    ImageResource vmStatusPoweringDown();

    @Source("images/vmStatus/vm_migration.png")
    ImageResource migrationImage();

    @Source("images/vmStatus/vm_run_runonce.png")
    ImageResource runOnceUpImage();

    @Source("images/vmStatus/suspened.png")
    ImageResource suspendedImage();

    @Source("images/double_arrow.png")
    ImageResource doubleArrowImage();

    @Source("images/host_prepare_to_migrate.png")
    ImageResource prepareImage();

    // Gluster Volume Rebalance
    @Source("images/glusterRebalance/rebalance_running.png")
    ImageResource rebalanceRunning();

    @Source("images/glusterRebalance/rebalance_failed.png")
    ImageResource rebalanceFailed();

    @Source("images/glusterRebalance/rebalance_completed.png")
    ImageResource rebalanceCompleted();

    @Source("images/glusterRebalance/rebalance_stopped.png")
    ImageResource rebalanceStoppped();
}

==> ovirt-engine-3.4.4.tar.gz: frontend/webadmin/modules/webadmin/src/main/java/org/ovirt/engine/ui/webadmin/ApplicationResources.java <==
package org.ovirt.engine.ui.webadmin;

import org.ovirt.engine.ui.common.CommonApplicationResources;

import com.google.gwt.resources.client.ImageResource;

public interface ApplicationResources extends CommonApplicationResources {

    @Source("images/bg.png")
    ImageResource bgImage();

    @Source("images/bookmark.gif")
    ImageResource bookmarkImage();

    @Source("images/but_erase_search_bar_text_normal.png")
    ImageResource clearSearchImage();

    @Source("images/but_erase_search_bar_text_hover.png")
    ImageResource clearSearchImage_mouseOver();

    @Source("images/but_erase_search_bar_text_mousedown.png")
    ImageResource clearSearchImage_mouseDown();

    @Source("images/cluster.png")
    ImageResource clusterImage();

    @Source("images/clusters.png")
    ImageResource clustersImage();

    @Source("images/console_disabled.png")
    ImageResource consoleDisabledImage();

    @Source("images/console.png")
    ImageResource consoleImage();

    @Source("images/datacenter.png")
    ImageResource dataCenterImage();

    @Source("images/datacenters.png")
    ImageResource dataCentersImage();

    @Override
    @Source("images/disk.png")
    ImageResource diskImage();

    @Source("images/error.gif")
    ImageResource errorImage();

    @Source("images/events_gray.png")
    ImageResource eventsGrayImage();

    @Source("images/events.png")
    ImageResource eventsImage();

    @Source("images/icon_foreman.png")
    ImageResource foremanImage();

    @Source("images/btn_guide_hover.png")
    ImageResource guideHoverMediumImage();

    @Source("images/guide.png")
    ImageResource guideImage();

    @Source("images/btn_guide.png")
    ImageResource guideMediumImage();

    @Source("images/btn_guide_pressed.png")
    ImageResource guidePressedMediumImage();

    @Source("images/icn_guide_disabled.png")
    ImageResource guideSmallDisabledImage();

    @Source("images/icn_guide.png")
    ImageResource guideSmallImage();

    @Source("images/bookmark.gif")
    ImageResource headerSearchBookmarkImage();

    @Source("images/search_button.png")
    ImageResource headerSearchButtonImage();

    @Source("images/host_error.gif")
    ImageResource hostErrorImage();

    @Source("images/host.png")
    ImageResource hostImage();

    @Source("images/host_installing.png")
    ImageResource hostInstallingImage();

    @Source("images/hosts.png")
    ImageResource hostsImage();

    @Source("images/Lock.png")
    ImageResource lockImage();

    @Source("images/icn_external_policy.png")
    ImageResource exteranlPolicyUnitImage();

    @Source("images/logo.png")
    ImageResource logoImage();

    @Source("images/host_maintenance.png")
    ImageResource maintenanceImage();

    @Source("images/many_desktops.png")
    ImageResource manyDesktopsImage();

    @Source("images/minus.png")
    ImageResource minusImage();

    @Source("images/monitor.png")
    ImageResource monitorImage();

    @Source("images/nonoperational.png")
    ImageResource nonOperationalImage();

    @Source("images/icon_openstack.png")
    ImageResource openstackImage();

    @Source("images/pause.gif")
    ImageResource pauseImage();

    @Source("images/icn_suspend_disabled.png")
    ImageResource suspendVmDisabledImage();

    @Source("images/icn_suspend_enabled.png")
    ImageResource suspendVmImage();

    @Source("images/play.gif")
    ImageResource playImage();

    @Source("images/plus_disabled.png")
    ImageResource plusDisabledImage();

    @Source("images/plus.png")
    ImageResource plusImage();

    @Source("images/icon_providers.png")
    ImageResource providersImage();

    @Source("images/log_warning.gif")
    ImageResource alertImage();

    @Source("images/tag_locked.png")
    ImageResource readOnlyTagImage();

    @Source("images/icn_play_disabled.png")
    ImageResource runVmDisabledImage();

    @Source("images/icn_play.png")
    ImageResource runVmImage();

    @Source("images/search_button.png")
    ImageResource searchButtonImage();

    @Source("images/split.png")
    ImageResource splitImage();

    @Source("images/split-rotate.png")
    ImageResource splitRotateImage();

    @Source("images/stop.gif")
    ImageResource stopImage();

    @Source("images/icn_stop_disabled.png")
    ImageResource stopVmDisabledImage();

    @Source("images/icn_stop.png")
    ImageResource stopVmImage();

    @Source("images/Reboot-13X13.png")
    ImageResource rebootImage();

    @Source("images/Reboot-disabled-13X13.png")
    ImageResource rebootDisabledImage();

    @Source("images/storages.png")
    ImageResource storagesImage();

    @Source("images/system.png")
    ImageResource systemImage();

    @Source("images/tag.png")
    ImageResource tagImage();

    @Source("images/icn_tag_link_disabled.gif")
    ImageResource tagLinkDisabledImage();

    @Source("images/icn_tag_link.png")
    ImageResource tagLinkImage();

    @Source("images/tag_pin_green.png")
    ImageResource tagPinGreenImage();

    @Source("images/tag_pin.png")
    ImageResource tagPinImage();

    @Source("images/torn_chain.png")
    ImageResource tornChainImage();

    @Source("images/unconfigured.png")
    ImageResource unconfiguredImage();

    @Source("images/upalert.png")
    ImageResource upalertImage();

    @Source("images/user_group.png")
    ImageResource userGroupImage();

    @Source("images/vm.png")
    ImageResource vmImage();

    @Source("images/window_bg.png")
    ImageResource windowBgImage();

    @Source("images/window_header.png")
    ImageResource windowHeaderImage();

    @Source("images/wrench.png")
    ImageResource wrenchImage();

    @Source("images/plusButton.png")
    ImageResource plusButtonImage();

    @Source("images/enlarge_bottom_panel.png")
    ImageResource enlargeFooterPanelImage();

    @Source("images/button/footer_button_start.png")
    ImageResource footerButtonUpStart();

    @Source("images/button/footer_button_stretch.png")
    ImageResource footerButtonUpStretch();

    @Source("images/button/footer_button_end.png")
    ImageResource footerButtonUpEnd();

    @Source("images/button/footer_button_Down_start.png")
    ImageResource footerButtonDownStart();

    @Source("images/button/footer_button_Down_stretch.png")
    ImageResource footerButtonDownStretch();

    @Source("images/button/footer_button_Down_end.png")
    ImageResource footerButtonDownEnd();

    @Source("images/icon_task.png")
    ImageResource iconTask();

    @Source("images/icon_audit.png")
    ImageResource iconAudit();

    @Source("images/icon_disable.png")
    ImageResource iconDisable();

    @Source("images/icon_enforce.png")
    ImageResource iconEnforce();

    @Source("images/icon_collapse_all.png")
    ImageResource collapseAllIcon();

    @Source("images/triangle_down.gif")
    ImageResource triangleDown();

    @Source("images/network/arrow_left.png")
    ImageResource arrowLeft();

    @Source("images/network/arrow_right_bottom.png")
    ImageResource arrowRightBottom();

    @Source("images/network/arrow_right_middle.png")
    ImageResource arrowRightMiddle();

    @Source("images/network/arrow_right_one.png")
    ImageResource arrowRightOne();

    @Source("images/network/arrow_right_top.png")
    ImageResource arrowRightTop();

    @Source("images/network/item_draggable.png")
    ImageResource itemDraggable();

    @Source("images/network/mgmt_net.png")
    ImageResource mgmtNetwork();

    @Source("images/network/network_monitor.png")
    ImageResource networkMonitor();

    @Source("images/network/network_vm.png")
    ImageResource networkVm();

    @Source("images/network/migration_network.png")
    ImageResource migrationNetwork();

    @Source("images/network/empty.png")
    ImageResource networkEmpty();

    @Source("images/network/nic_down.png")
    ImageResource nicDown();

    @Source("images/network/nic_up.png")
    ImageResource nicUp();

    @Source("images/network/edit_hover.png")
    ImageResource editHover();

    @Source("images/network/edit_mousedown.png")
    ImageResource editMouseDown();

    @Source("images/network/nic_icon.png")
    ImageResource nicIcon();

    @Source("images/network/bond.png")
    ImageResource bond();

    @Source("images/network/network_not_sync.png")
    ImageResource networkNotSyncImage();

    @Source("images/network/but_erase_net_mousedown.png")
    ImageResource butEraseNetMousedown();

    @Source("images/network/but_erase_net_hover.png")
    ImageResource butEraseNetHover();

    @Source("images/cluster_gluster.png")
    ImageResource glusterClusterImage();

    @Source("images/single_volume.png")
    ImageResource volumeImage();

    @Source("images/multiple_volumes.png")
    ImageResource volumesImage();

    @Source("images/icn_tree_network.png")
    ImageResource networkTreeImage();

    @Source("images/icn_tree_networks.png")
    ImageResource networksTreeImage();

    // Vm Types
    @Source("images/vmType/desktop.gif")
    ImageResource desktopImage();

    @Source("images/vmType/server.png")
    ImageResource serverImage();

    @Source("images/vmType/vm_desktop_stateless.png")
    ImageResource desktopStateless();

    @Source("images/vmType/vm_server_stateless.png")
    ImageResource serverStateless();

    // custom statuses
    @Source("images/vmStatus/running.png")
    ImageResource vmStatusRunning();

    @Source("images/vmStatus/starting.png")
    ImageResource vmStatusStarting();

    @Source("images/vmStatus/rebootInProgress.png")
    ImageResource rebootInProgress();

    @Source("images/vmStatus/wait.png")
    ImageResource vmStatusWait();

    @Source("images/vmStatus/waitForLaunch.png")
    ImageResource waitForLaunch();

    @Source("images/vmStatus/down.png")
    ImageResource downStatusImage();

    @Source("images/vmStatus/stopping.png")
    ImageResource vmStatusPoweringDown();

    @Source("images/vmStatus/vm_migration.png")
    ImageResource migrationImage();

    @Source("images/vmStatus/vm_run_runonce.png")
    ImageResource runOnceUpImage();

    @Source("images/vmStatus/suspened.png")
    ImageResource suspendedImage();

    @Source("images/double_arrow.png")
    ImageResource doubleArrowImage();

    @Source("images/host_prepare_to_migrate.png")
    ImageResource prepareImage();

    // Gluster Volume Async Tasks
    @Source("images/glusterAsyncTasks/rebalance_running.png")
    ImageResource rebalanceRunning();

    @Source("images/glusterAsyncTasks/rebalance_failed.png")
    ImageResource rebalanceFailed();

    @Source("images/glusterAsyncTasks/rebalance_completed.png")
    ImageResource rebalanceCompleted();

    @Source("images/glusterAsyncTasks/rebalance_stopped.png")
    ImageResource rebalanceStoppped();

    @Source("images/glusterAsyncTasks/remove_brick_running.png")
    ImageResource removeBrickRunning();

    @Source("images/glusterAsyncTasks/remove_brick_stopped.png")
    ImageResource removeBrickStopped();

    @Source("images/glusterAsyncTasks/remove_brick_failed.png")
    ImageResource removeBrickFailed();

    @Source("images/glusterAsyncTasks/remove_brick_commit_required.png")
    ImageResource removeBrickCommitRequired();

}
